@@ -1,11 +1,13 @@
 """
 Mikrotik API Client.
+https://wiki.mikrotik.com/wiki/Manual:API
 """
 import asyncio
 from binascii import hexlify, unhexlify
 from collections import namedtuple
 from hashlib import md5
 import itertools
+from keyword import iskeyword
 import logging
 import ssl
 import struct
@@ -35,13 +37,18 @@ class MikrotikApiClient:
             self._ssl.check_hostname = False
             self._ssl.verify_mode = ssl.CERT_NONE
 
-    async def _get_results_data(self, cmd, include_disabled=False):
+    async def _get_results_data(self, cmd, include_disabled=False, props=None, query=None):
         """Run a command and return a list of namedtuple results."""
         if not self._logged_in:
             await self.login()
         results = []
         try:
-            res = await self.talk([cmd])
+            sentence = [cmd]
+            if props:  # comma-separated list of property names to return
+                sentence.append(f'=.proplist={props}')
+            if query:  # query words
+                sentence.extend(query)
+            res = await self.talk(sentence)
         except MikrotikApiError as err:
             if str(err) == 'no such command prefix':
                 return []
@@ -61,12 +68,14 @@ class MikrotikApiClient:
                     results.append(row)
         if results:
             keys = list(sorted(set(itertools.chain.from_iterable(results))))
-            nt = namedtuple('Row', [x.replace('.', '').replace('-', '_') for x in keys])
+            fields = [x.replace('.', '').replace('-', '_') for x in keys]
+            fields = [x.upper() if iskeyword(x) else x for x in fields]
+            nt = namedtuple('Row', fields)
         return [nt(*[x.get(k) for k in keys]) for x in results]
 
-    async def _get_results(self, cmd, include_disabled=False):
+    async def _get_results(self, cmd, include_disabled=False, props=None, query=None):
         try:
-            return await asyncio.wait_for(self._get_results_data(cmd, include_disabled), timeout=self._timeout)
+            return await asyncio.wait_for(self._get_results_data(cmd, include_disabled, props, query), timeout=self._timeout)
         except asyncio.CancelledError:
             logging.info('Cancelled "%s" operation for %s', cmd, self.host)
             await self.close()
@@ -209,6 +218,6 @@ class MikrotikApiClient:
             ret += s.decode('iso-8859-1')
         return ret
 
-    async def get(self, cmd, include_disabled=False):
+    async def get(self, cmd, include_disabled=False, props=None, query=None):
         """Run a command and get the results as a list of Row namedtuples."""
-        return await self._get_results(cmd)
+        return await self._get_results(cmd, include_disabled, props, query)
